@@ -1,9 +1,17 @@
+"""
+Helper classes and methods used in mixins implementing various commands.
+Unlike _helpers.py, here the methods should be used only in mixins.
+"""
 import functools
 import math
 import re
 
 from . import _msgs as msgs
-from ._helpers import MAX_STRING_SIZE, null_terminate, SimpleError
+from ._helpers import null_terminate, SimpleError
+
+MAX_STRING_SIZE = 512 * 1024 * 1024
+SUPPORTED_COMMANDS = dict()  # Dictionary of supported commands name => Signature
+COMMANDS_WITH_SUB = set()  # Commands with sub-commands
 
 
 class Key:
@@ -73,10 +81,11 @@ class CommandItem:
     def updated(self):
         self._modified = True
 
-    def writeback(self):
+    def writeback(self, remove_empty_val=True):
         if self._modified:
             self.db.notify_watch(self.key)
-            if not isinstance(self.value, bytes) and not self.value:
+            if (not isinstance(self.value, bytes) and (
+                    self.value is None or (not self.value and remove_empty_val))):
                 self.db.pop(self.key, None)
                 return
             else:
@@ -295,11 +304,12 @@ class StringTest:
 
 
 class Signature:
-    def __init__(self, name, fixed, repeat=(), flags=""):
+    def __init__(self, name, func_name, fixed, repeat=(), flags=""):
         self.name = name
+        self.func_name = func_name
         self.fixed = fixed
         self.repeat = repeat
-        self.flags = flags
+        self.flags = set(flags)
 
     def check_arity(self, args, version):
         if len(args) != len(self.fixed):
@@ -352,9 +362,20 @@ class Signature:
 
 
 def command(*args, **kwargs):
+    def create_signature(func, cmd_name):
+        if ' ' in cmd_name:
+            COMMANDS_WITH_SUB.add(cmd_name.split(' ')[0])
+        SUPPORTED_COMMANDS[cmd_name] = Signature(cmd_name, func.__name__, *args, **kwargs)
+
     def decorator(func):
-        name = kwargs.pop('name', func.__name__)
-        func._fakeredis_sig = Signature(name, *args, **kwargs)
+        cmd_names = kwargs.pop('name', func.__name__)
+        if isinstance(cmd_names, list):  # Support for alias commands
+            for cmd_name in cmd_names:
+                create_signature(func, cmd_name.lower())
+        elif isinstance(cmd_names, str):
+            create_signature(func, cmd_names.lower())
+        else:
+            raise ValueError("command name should be a string or list of strings")
         return func
 
     return decorator
@@ -381,3 +402,15 @@ def fix_range(start, end, length):
         return -1, -1
     end = min(end, length - 1)
     return start, end + 1
+
+
+def fix_range_string(start, end, length):
+    # Negative number handling is based on the redis source code
+    if 0 > start > end and end < 0:
+        return -1, -1
+    if start < 0:
+        start = max(0, start + length)
+    if end < 0:
+        end = max(0, end + length)
+    end = min(end, length - 1)
+    return start, end + 1
