@@ -50,6 +50,8 @@ RESTORE_KEY_EXISTS = "BUSYKEY Target key name already exists."
 RESTORE_INVALID_CHECKSUM_MSG = "ERR DUMP payload version or checksum are wrong"
 RESTORE_INVALID_TTL_MSG = "ERR Invalid TTL value, must be >= 0"
 JSON_WRONG_REDIS_TYPE = "ERR Existing key has wrong Redis type"
+JSON_KEY_NOT_FOUND = "ERR could not perform this operation on a key that doesn't exist"
 
 FLAG_NO_SCRIPT = 's'  # Command not allowed in scripts
-FLAG_TRANSACTION = 't'  # Command not allowed in scripts
+FLAG_LEAVE_EMPTY_VAL = 'v'
+FLAG_TRANSACTION = 't'
